@@ -25,6 +25,7 @@
 #define AKONADI_AGENTBASE_H
 
 #include "akonadi_export.h"
+#include <akonadi/item.h>
 
 #include <KDE/KApplication>
 
@@ -295,6 +296,66 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
         virtual void collectionChanged( const Akonadi::Collection &collection, const QSet<QByteArray> &changedAttributes );
     };
 
+    /**
+     * BC extension of ObserverV2 with support for batch operations
+     *
+     * @warning When using ObserverV3, you will never get single-item notifications
+     * from AgentBase::Observer, even when you don't reimplement corresponding batch
+     * method from ObserverV3. For instance, when you don't reimplement itemsRemoved()
+     * here, you will not get any notifications about item removal whatsoever!
+     *
+     * @since 4.11
+     */
+    class AKONADI_EXPORT ObserverV3 : public ObserverV2 // krazy:exclude=dpointer
+    {
+      public:
+        /**
+         * Reimplement to handle changes in flags of existing items
+         *
+         * @warning When using ObserverV3, you will never get notifications about
+         * flag changes via Observer::itemChanged(), even when you don't reimplement
+         * itemsFlagsChanged()!
+         *
+         * @param item The changed item.
+         * @param addedFlags Flags that have been added to the item
+         * @param removedFlags Flags that have been removed from the item
+         */
+        virtual void itemsFlagsChanged( const Akonadi::Item::List &items, const QSet<QByteArray> &addedFlags, const QSet<QByteArray> &removedFlags );
+
+        /**
+         * Reimplement to handle batch notification about items deletion.
+         *
+         * @param items List of deleted items
+         */
+        virtual void itemsRemoved( const Akonadi::Item::List &items );
+
+        /**
+         * Reimplement to handle batch notification about items move
+         *
+         * @param items List of moved items
+         * @param sourceCollection Collection from where the items were moved
+         * @param destinationCollection Collection to which the items were moved
+         */
+        virtual void itemsMoved( const Akonadi::Item::List &items, const Akonadi::Collection &sourceCollection,
+                                 const Akonadi::Collection &destinationCollection );
+
+        /**
+         * Reimplement to handle batch notifications about items linking.
+         *
+         * @param items Linked items
+         * @param collection Collection to which the items have been linked
+         */
+        virtual void itemsLinked( const Akonadi::Item::List &items, const Akonadi::Collection &collection );
+
+        /**
+         * Reimplement to handle batch notifications about items unlinking.
+         *
+         * @param items Unlinked items
+         * @param collection Collection from which the items have been unlinked
+         */
+        virtual void itemsUnlinked( const Akonadi::Item::List &items, const Akonadi::Collection &collection );
+    };
+
     /**
      * This enum describes the different states the
      * agent can be in.
@@ -326,6 +387,9 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      *   AKONADI_AGENT_MAIN( MyAgent )
      *
      * @endcode
+     *
+     * @param argc number of arguments
+     * @param argv arguments for the function
      */
     template <typename T>
     static int init( int argc, char **argv )
@@ -424,6 +488,7 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      * This method is used to set the name of the agent.
      *
      * @since 4.3
+     * @param name name of the agent
      */
     //FIXME_API: make sure location is renamed to this by agentbase
     void setAgentName( const QString &name );
@@ -590,6 +655,7 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
      * @since 4.2
      * @todo use this in combination with Solid::Networking::Notifier to change
      *       the onLine status of the agent.
+     * @param needsNetwork @c true if the agents needs network. Defaults to @c false
      */
     void setNeedsNetwork( bool needsNetwork );
 
@@ -608,6 +674,7 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
     /**
      * This method is called whenever the @p online status has changed.
      * Reimplement this method to react on online status changes.
+     * @param online online status
      */
     virtual void doSetOnline( bool online );
 
@@ -615,6 +682,7 @@ class AKONADI_EXPORT AgentBase : public QObject, protected QDBusContext
     //@cond PRIVATE
     static QString parseArguments( int, char** );
     static int init( AgentBase *r );
+    void setOnlineInternal( bool state );
 
     // D-Bus interface stuff
     void abort();
