@@ -18,8 +18,8 @@
   02110-1301, USA.
 */
 
-#ifndef AKONADI_FREEBUSYDOWNLOADJOB_H
-#define AKONADI_FREEBUSYDOWNLOADJOB_H
+#ifndef AKONADI_FREEBUSYDOWNLOADJOB_P_H
+#define AKONADI_FREEBUSYDOWNLOADJOB_P_H
 
 #include <KJob>
 #include <KUrl>
