@@ -241,16 +241,19 @@ void ITIPHandler::publishInformation( const KCalCore::Incidence::Ptr &incidence,
   delete publishdlg;
 }
 
-void ITIPHandler::sendAsICalendar( const KCalCore::Incidence::Ptr &incidence,
+void ITIPHandler::sendAsICalendar( const KCalCore::Incidence::Ptr &originalIncidence,
                                    QWidget *parentWidget )
 {
   Q_UNUSED( parentWidget );
-  Q_ASSERT( incidence );
-  if ( !incidence ) {
+  Q_ASSERT( originalIncidence );
+  if ( !originalIncidence ) {
     kError() << "Invalid incidence";
     return;
   }
 
+  // Clone so we can change organizer and recurid
+  KCalCore::Incidence::Ptr incidence = KCalCore::Incidence::Ptr( originalIncidence->clone() );
+
   KPIMIdentities::IdentityManager identityManager;
 
   QPointer<Akonadi::PublishDialog> publishdlg = new Akonadi::PublishDialog;
@@ -262,6 +265,11 @@ void ITIPHandler::sendAsICalendar( const KCalCore::Incidence::Ptr &incidence,
                                                        Akonadi::CalendarUtils::email() ) ) );
     }
 
+    if ( incidence->hasRecurrenceId() ) {
+      // For an individual occurrence, recur id doesn't make sense, since we're not sending the whole recurrence series.
+      incidence->setRecurrenceId(KDateTime());
+    }
+
     KCalCore::ICalFormat format;
     const QString from = Akonadi::CalendarUtils::email();
     const bool bccMe = Akonadi::CalendarSettings::self()->bcc();
