@@ -34,8 +34,8 @@
 
 using namespace Akonadi;
 
-Q_DECLARE_METATYPE( KPIMIdentities::Identity );
-Q_DECLARE_METATYPE( KCalCore::Incidence::Ptr );
+Q_DECLARE_METATYPE( KPIMIdentities::Identity )
+Q_DECLARE_METATYPE( KCalCore::Incidence::Ptr )
 
 class MailClientTest : public QObject
 {
