@@ -19,15 +19,17 @@
 
 #include "collectionrequester.h"
 #include "collectiondialog.h"
+#include "entitydisplayattribute.h"
 
 #include <klineedit.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kpushbutton.h>
+#include <kicon.h>
 #include <kstandardshortcut.h>
 
 #include <QtCore/QEvent>
-#include <QtGui/QAction>
-#include <QtGui/QApplication>
+#include <QAction>
+#include <QApplication>
 
 using namespace Akonadi;
 
@@ -88,6 +90,7 @@ void CollectionRequester::Private::init()
   q->connect( openAction, SIGNAL(triggered(bool)), q, SLOT(_k_slotOpenDialog()) );
 
   collectionDialog = new CollectionDialog( q );
+  collectionDialog->setWindowIcon( KIcon( QLatin1String( "akonadi" ) ) );
   collectionDialog->setCaption( i18n( "Select a collection" ) );
   collectionDialog->setSelectionMode( QAbstractItemView::SingleSelection );
 }
@@ -96,8 +99,9 @@ void CollectionRequester::Private::_k_slotOpenDialog()
 {
   CollectionDialog *dlg = collectionDialog;
 
-  if ( dlg->exec() != QDialog::Accepted )
+  if ( dlg->exec() != QDialog::Accepted ) {
     return;
+  }
 
   const Akonadi::Collection collection = dlg->selectedCollection();
   q->setCollection( collection );
@@ -136,42 +140,52 @@ Collection CollectionRequester::collection() const
 void CollectionRequester::setCollection( const Collection& collection )
 {
   d->collection = collection;
-  d->edit->setText( collection.isValid() ? collection.name() : QString() );
+  QString name;
+  if ( collection.isValid() ) {
+    name = collection.displayName();
+  }
+
+  d->edit->setText( name );
   emit collectionChanged( collection );
 }
 
 void CollectionRequester::setMimeTypeFilter( const QStringList &mimeTypes )
 {
-  if ( d->collectionDialog )
+  if ( d->collectionDialog ) {
     d->collectionDialog->setMimeTypeFilter( mimeTypes );
+  }
 }
 
 QStringList CollectionRequester::mimeTypeFilter() const
 {
-  if ( d->collectionDialog )
+  if ( d->collectionDialog ) {
     return d->collectionDialog->mimeTypeFilter();
-  else
+  } else {
     return QStringList();
+  }
 }
 
 void CollectionRequester::setAccessRightsFilter( Collection::Rights rights )
 {
-  if ( d->collectionDialog )
+  if ( d->collectionDialog ) {
     d->collectionDialog->setAccessRightsFilter( rights );
+  }
 }
 
 Collection::Rights CollectionRequester::accessRightsFilter() const
 {
-  if ( d->collectionDialog )
+  if ( d->collectionDialog ) {
     return d->collectionDialog->accessRightsFilter();
-  else
+  } else {
     return Akonadi::Collection::ReadOnly;
+  }
 }
 
 void CollectionRequester::changeCollectionDialogOptions( CollectionDialog::CollectionDialogOptions options )
 {
-  if ( d->collectionDialog )
+  if ( d->collectionDialog ) {
     d->collectionDialog->changeCollectionDialogOptions( options );
+  }
 }
 
-#include "collectionrequester.moc"
+#include "moc_collectionrequester.cpp"
