@@ -28,6 +28,8 @@
 #include <akonadi/item.h>
 #include <kabc/contactgroup.h>
 #include <klocale.h>
+#include <klocalizedstring.h>
+#include <kglobal.h>
 #include <kpushbutton.h>
 #include <klineedit.h>
 
