@@ -22,7 +22,6 @@
 #ifndef SOUNDEDITWIDGET_H
 #define SOUNDEDITWIDGET_H
 
-#include <QtCore/QPoint>
 #include <QToolButton>
 
 namespace KABC
@@ -37,7 +36,7 @@ class SoundEditWidget : public QToolButton
   Q_OBJECT
 
   public:
-    SoundEditWidget( QWidget *parent = 0 );
+    explicit SoundEditWidget( QWidget *parent = 0 );
     ~SoundEditWidget();
 
     void loadContact( const KABC::Addressee &contact );
