@@ -25,7 +25,7 @@
 #include "kedittagsdialog_p.h"
 
 #include <kicon.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <ksqueezedtextlabel.h>
 
 #include <QHBoxLayout>
@@ -36,29 +36,29 @@ TagWidget::TagWidget( QWidget *parent )
 {
   QHBoxLayout *layout = new QHBoxLayout( this );
   mTagLabel = new KSqueezedTextLabel;
-  mTagLabel->setFrameStyle( QFrame::Panel | QFrame::Sunken );
+  mTagLabel->setFrameStyle( QFrame::StyledPanel | QFrame::Sunken );
   layout->addWidget( mTagLabel );
 
-  mEditButton = new QToolButton;
-  mEditButton->setText( QLatin1String( "..." ) );
-  layout->addWidget( mEditButton, Qt::AlignRight );
+  QToolButton *editButton = new QToolButton;
+  editButton->setText( i18n( "..." ) );
+  layout->addWidget( editButton, Qt::AlignRight );
 
   layout->setStretch( 0, 10 );
 
-  connect( mEditButton, SIGNAL(clicked()), SLOT(editTags()) );
+  connect( editButton, SIGNAL(clicked()), SLOT(editTags()) );
 }
 
 TagWidget::~TagWidget()
 {
 }
 
-void TagWidget::setTags( const QVector<Nepomuk::Tag> &tags )
+void TagWidget::setTags( const QVector<Nepomuk2::Tag> &tags )
 {
   mTags = tags;
   updateView();
 }
 
-QVector<Nepomuk::Tag> TagWidget::tags() const
+QVector<Nepomuk2::Tag> TagWidget::tags() const
 {
   return mTags;
 }
@@ -75,7 +75,7 @@ void TagWidget::editTags()
 void TagWidget::updateView()
 {
   QString text;
-  foreach ( const Nepomuk::Tag &tag, mTags ) {
+  foreach ( const Nepomuk2::Tag &tag, mTags ) {
     const QString separator = ( tag == mTags.last() ? QString() : QLatin1String( ", " ) );
     text += tag.genericLabel() + separator;
   }
