@@ -45,7 +45,7 @@ class EntityMimeTypeFilterModelPrivate
     {
     }
 
-    Q_DECLARE_PUBLIC(EntityMimeTypeFilterModel)
+    Q_DECLARE_PUBLIC( EntityMimeTypeFilterModel )
     EntityMimeTypeFilterModel *q_ptr;
 
     QStringList includedMimeTypes;
@@ -71,43 +71,44 @@ EntityMimeTypeFilterModel::~EntityMimeTypeFilterModel()
 
 void EntityMimeTypeFilterModel::addMimeTypeInclusionFilters(const QStringList &typeList)
 {
-  Q_D(EntityMimeTypeFilterModel);
+  Q_D( EntityMimeTypeFilterModel );
   d->includedMimeTypes << typeList;
   invalidateFilter();
 }
 
 void EntityMimeTypeFilterModel::addMimeTypeExclusionFilters(const QStringList &typeList)
 {
-  Q_D(EntityMimeTypeFilterModel);
+  Q_D( EntityMimeTypeFilterModel );
   d->excludedMimeTypes << typeList;
   invalidateFilter();
 }
 
 void EntityMimeTypeFilterModel::addMimeTypeInclusionFilter(const QString &type)
 {
-  Q_D(EntityMimeTypeFilterModel);
+  Q_D( EntityMimeTypeFilterModel );
   d->includedMimeTypes << type;
   invalidateFilter();
 }
 
 void EntityMimeTypeFilterModel::addMimeTypeExclusionFilter(const QString &type)
 {
-  Q_D(EntityMimeTypeFilterModel);
+  Q_D( EntityMimeTypeFilterModel );
   d->excludedMimeTypes << type;
   invalidateFilter();
 }
 
 bool EntityMimeTypeFilterModel::filterAcceptsColumn( int sourceColumn, const QModelIndex &sourceParent ) const
 {
-    if (sourceColumn >= columnCount(mapFromSource(sourceParent)))
+    if ( sourceColumn >= columnCount( mapFromSource( sourceParent ) ) ) {
         return false;
+    }
     return QSortFilterProxyModel::filterAcceptsColumn( sourceColumn, sourceParent );
 }
 
 bool EntityMimeTypeFilterModel::filterAcceptsRow( int sourceRow, const QModelIndex &sourceParent) const
 {
-  Q_D(const EntityMimeTypeFilterModel);
-  const QModelIndex idx = sourceModel()->index(sourceRow, 0, sourceParent);
+  Q_D( const EntityMimeTypeFilterModel );
+  const QModelIndex idx = sourceModel()->index( sourceRow, 0, sourceParent );
 
   const Akonadi::Item item = idx.data( EntityTreeModel::ItemRole ).value<Akonadi::Item>();
 
@@ -118,29 +119,32 @@ bool EntityMimeTypeFilterModel::filterAcceptsRow( int sourceRow, const QModelInd
 
   const QString rowMimetype = idx.data( EntityTreeModel::MimeTypeRole ).toString();
 
-  if ( d->excludedMimeTypes.contains( rowMimetype ) )
+  if ( d->excludedMimeTypes.contains( rowMimetype ) ) {
     return false;
-  if ( d->includedMimeTypes.isEmpty() || d->includedMimeTypes.contains( rowMimetype ) )
+  }
+  if ( d->includedMimeTypes.isEmpty() ||
+       d->includedMimeTypes.contains( rowMimetype ) ) {
     return true;
+  }
 
   return false;
 }
 
 QStringList EntityMimeTypeFilterModel::mimeTypeInclusionFilters() const
 {
-  Q_D(const EntityMimeTypeFilterModel);
+  Q_D( const EntityMimeTypeFilterModel );
   return d->includedMimeTypes;
 }
 
 QStringList EntityMimeTypeFilterModel::mimeTypeExclusionFilters() const
 {
-  Q_D(const EntityMimeTypeFilterModel);
+  Q_D( const EntityMimeTypeFilterModel );
   return d->excludedMimeTypes;
 }
 
 void EntityMimeTypeFilterModel::clearFilters()
 {
-  Q_D(EntityMimeTypeFilterModel);
+  Q_D( EntityMimeTypeFilterModel );
   d->includedMimeTypes.clear();
   d->excludedMimeTypes.clear();
   invalidateFilter();
@@ -148,35 +152,39 @@ void EntityMimeTypeFilterModel::clearFilters()
 
 void EntityMimeTypeFilterModel::setHeaderGroup(EntityTreeModel::HeaderGroup headerGroup)
 {
-  Q_D(EntityMimeTypeFilterModel);
+  Q_D( EntityMimeTypeFilterModel );
   d->m_headerGroup = headerGroup;
 }
 
 QVariant EntityMimeTypeFilterModel::headerData(int section, Qt::Orientation orientation, int role ) const
 {
-  if (!sourceModel())
+  if ( !sourceModel() ) {
     return QVariant();
+  }
 
-  Q_D(const EntityMimeTypeFilterModel);
-  role += (EntityTreeModel::TerminalUserRole * d->m_headerGroup);
-  return sourceModel()->headerData(section, orientation, role);
+  Q_D( const EntityMimeTypeFilterModel );
+  role += ( EntityTreeModel::TerminalUserRole * d->m_headerGroup );
+  return sourceModel()->headerData( section, orientation, role );
 }
 
 QModelIndexList EntityMimeTypeFilterModel::match( const QModelIndex& start, int role, const QVariant& value, int hits, Qt::MatchFlags flags ) const
 {
-  if ( !sourceModel() )
+  if ( !sourceModel() ) {
     return QModelIndexList();
+  }
 
   if ( EntityTreeModel::AmazingCompletionRole != role ) {
-    if ( role < Qt::UserRole )
+    if ( role < Qt::UserRole ) {
       return QSortFilterProxyModel::match( start, role, value, hits, flags );
+    }
 
     QModelIndexList list;
     QModelIndex proxyIndex;
     foreach ( const QModelIndex &idx, sourceModel()->match( mapToSource( start ), role, value, hits, flags ) ) {
-      proxyIndex = mapFromSource(idx);
-      if (proxyIndex.isValid())
+      proxyIndex = mapFromSource( idx );
+      if ( proxyIndex.isValid() ) {
         list << proxyIndex;
+      }
     }
 
     return list;
@@ -195,60 +203,66 @@ QModelIndexList EntityMimeTypeFilterModel::match( const QModelIndex& start, int
     proxyIndex = mapFromSource( *it );
 
     // Any filtered indexes will be invalid when mapped.
-    if ( !proxyIndex.isValid() )
+    if ( !proxyIndex.isValid() ) {
       continue;
+    }
 
     // Inserting in a QMap gives us sorting by key for free.
     proxyMap.insert( proxyIndex.row(), proxyIndex );
   }
 
-  if ( hits == -1 )
+  if ( hits == -1 ) {
     return proxyMap.values();
+  }
 
   return proxyMap.values().mid( 0, hits );
 }
 
 int EntityMimeTypeFilterModel::columnCount(const QModelIndex &parent) const
 {
-  Q_D(const EntityMimeTypeFilterModel);
+  Q_D( const EntityMimeTypeFilterModel );
 
-  if (!sourceModel())
+  if ( !sourceModel() ) {
     return 0;
+  }
 
-  const QVariant value = sourceModel()->data(mapToSource(parent), EntityTreeModel::ColumnCountRole + (EntityTreeModel::TerminalUserRole * d->m_headerGroup));
-  if ( !value.isValid() )
+  const QVariant value = sourceModel()->data( mapToSource( parent ), EntityTreeModel::ColumnCountRole + ( EntityTreeModel::TerminalUserRole * d->m_headerGroup ) );
+  if ( !value.isValid() ) {
     return 0;
+  }
 
   return value.toInt();
 }
 
 bool EntityMimeTypeFilterModel::hasChildren(const QModelIndex &parent) const
 {
-  if (!sourceModel())
+  if ( !sourceModel() ) {
     return false;
+  }
 
   // QSortFilterProxyModel implementation is buggy in that it emits rowsAboutToBeInserted etc
   // only after the source model has emitted rowsInserted, instead of emitting it when the
   // source model emits rowsAboutToBeInserted. That means that the source and the proxy are out
   // of sync around the time of insertions, so we can't use the optimization below.
-  return rowCount(parent) > 0;
+  return rowCount( parent ) > 0;
 #if 0
 
-  if ( !parent.isValid() )
-    return sourceModel()->hasChildren(parent);
+  if ( !parent.isValid() ) {
+    return sourceModel()->hasChildren( parent );
+  }
 
-  Q_D(const EntityMimeTypeFilterModel);
-  if ( EntityTreeModel::ItemListHeaders == d->m_headerGroup)
+  Q_D( const EntityMimeTypeFilterModel );
+  if ( EntityTreeModel::ItemListHeaders == d->m_headerGroup ) {
     return false;
+  }
 
-  if ( EntityTreeModel::CollectionTreeHeaders == d->m_headerGroup )
-  {
+  if ( EntityTreeModel::CollectionTreeHeaders == d->m_headerGroup ) {
     QModelIndex childIndex = parent.child( 0, 0 );
-    while ( childIndex.isValid() )
-    {
+    while ( childIndex.isValid() ) {
       Collection col = childIndex.data( EntityTreeModel::CollectionRole ).value<Collection>();
-      if (col.isValid())
+      if ( col.isValid() ) {
         return true;
+      }
       childIndex = childIndex.sibling( childIndex.row() + 1, childIndex.column() );
     }
   }
@@ -258,11 +272,11 @@ bool EntityMimeTypeFilterModel::hasChildren(const QModelIndex &parent) const
 
 bool EntityMimeTypeFilterModel::canFetchMore( const QModelIndex &parent ) const
 {
-  Q_D(const EntityMimeTypeFilterModel);
-  if ( EntityTreeModel::CollectionTreeHeaders == d->m_headerGroup )
+  Q_D( const EntityMimeTypeFilterModel );
+  if ( EntityTreeModel::CollectionTreeHeaders == d->m_headerGroup ) {
     return false;
-  return QSortFilterProxyModel::canFetchMore(parent);
+  }
+  return QSortFilterProxyModel::canFetchMore( parent );
 }
 
-#include "entitymimetypefiltermodel.moc"
 
