@@ -17,8 +17,8 @@
     02110-1301, USA.
 */
 
-#ifndef LOCALFOLDERSTESTREQUESTJOB_H
-#define LOCALFOLDERSTESTREQUESTJOB_H
+#ifndef LOCALFOLDERSREQUESTJOBTEST_H
+#define LOCALFOLDERSREQUESTJOBTEST_H
 
 #include <QtCore/QObject>
 
