@@ -21,6 +21,7 @@
 #include "agentmanager.h"
 #include "dbusconnectionpool.h"
 #include "session_p.h"
+#include "servermanager.h"
 #include "servermanager_p.h"
 
 #include <akonadi/private/xdgbasedirs_p.h>
@@ -28,7 +29,7 @@
 #include <KDebug>
 #include <KIcon>
 #include <KFileDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
 #include <KRun>
 #include <KStandardDirs>
@@ -39,16 +40,14 @@
 #include <QtCore/QSettings>
 #include <QtCore/QTextStream>
 #include <QtDBus/QtDBus>
-#include <QtGui/QApplication>
-#include <QtGui/QClipboard>
-#include <QtGui/QStandardItemModel>
+#include <QApplication>
+#include <QClipboard>
+#include <QStandardItemModel>
 #include <QtSql/QSqlDatabase>
 #include <QtSql/QSqlError>
 
 // @cond PRIVATE
 
-#define AKONADI_CONTROL_SERVICE QLatin1String( "org.freedesktop.Akonadi.Control" )
-#define AKONADI_SERVER_SERVICE QLatin1String( "org.freedesktop.Akonadi" )
 #define AKONADI_SEARCH_SERVICE QLatin1String( "org.kde.nepomuk.services.nepomukqueryservice" )
 
 using namespace Akonadi;
@@ -403,7 +402,7 @@ void SelfTestDialog::testAkonadiCtl()
 
 void SelfTestDialog::testServerStatus()
 {
-  if ( DBusConnectionPool::threadConnection().interface()->isServiceRegistered( AKONADI_CONTROL_SERVICE ) ) {
+  if ( DBusConnectionPool::threadConnection().interface()->isServiceRegistered( ServerManager::serviceName(ServerManager::Control) ) ) {
     report( Success, ki18n( "Akonadi control process registered at D-Bus." ),
                    ki18n( "The Akonadi control process is registered at D-Bus which typically indicates it is operational." ) );
   } else {
@@ -412,7 +411,7 @@ void SelfTestDialog::testServerStatus()
                        "or encountered a fatal error during startup."  ) );
   }
 
-  if ( DBusConnectionPool::threadConnection().interface()->isServiceRegistered( AKONADI_SERVER_SERVICE ) ) {
+  if ( DBusConnectionPool::threadConnection().interface()->isServiceRegistered( ServerManager::serviceName(ServerManager::Server) ) ) {
     report( Success, ki18n( "Akonadi server process registered at D-Bus." ),
                    ki18n( "The Akonadi server process is registered at D-Bus which typically indicates it is operational." ) );
   } else {
@@ -636,7 +635,7 @@ void SelfTestDialog::saveReport()
   const QString defaultFileName = QLatin1String( "akonadi-selftest-report-" )
                    + QDate::currentDate().toString( QLatin1String( "yyyyMMdd" ) )
                    + QLatin1String( ".txt" );
-  const QString fileName =  KFileDialog::getSaveFileName( defaultFileName, QString(), this,
+  const QString fileName =  KFileDialog::getSaveFileName( QUrl(defaultFileName), QString(), this,
                                                           i18n( "Save Test Report" ) );
   if ( fileName.isEmpty() )
     return;
@@ -665,4 +664,4 @@ void SelfTestDialog::linkActivated(const QString & link)
 
 // @endcond
 
-#include "selftestdialog_p.moc"
+#include "moc_selftestdialog_p.cpp"
