@@ -87,13 +87,24 @@ class AKONADI_EXPORT SpecialCollections : public QObject
     /**
      * Registers the given @p collection as a special collection
      * with the given @p type.
-     *
+     * @param type the special type of @c collection
+     * @param collection the given collection to register
      * The collection must be owned by a valid resource.
      * Registering a new collection of a previously registered type forgets the
      * old collection.
      */
     bool registerCollection( const QByteArray &type, const Akonadi::Collection &collection );
 
+    /**
+     * Sets the special collection attribute which marks @p collection as being a special
+     * collection of type @p type.
+     * This is typically used by configuration dialog for resources, when the user can choose
+     * a specific special collection (ex: IMAP trash).
+     *
+     * @since 4.11
+     */
+    static void setSpecialCollectionType(const QByteArray &type, const Akonadi::Collection &collection);
+
     /**
      * Returns whether the default resource has a special collection of
      * the given @p type.
