@@ -29,7 +29,7 @@
 
 #include <kdebug.h>
 #include <kiconloader.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kio/global.h>
 
 #include <QApplication>
@@ -153,9 +153,9 @@ class StatisticsProxyModel::Private
       for ( int i = 0; i < 2; i++ ) {
         iconPath = KIconLoader::global()->iconPath( iconName, -iconSizes[ i ], true );
         if ( !iconPath.isEmpty() ) {
-	  icon_size_found = iconSizes[ i ];
+          icon_size_found = iconSizes[ i ];
           break;
-	}
+        }
       }
 
       if ( iconPath.isEmpty() ) {
