@@ -40,7 +40,7 @@
 #include "ldif_p.h"
 
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QtCore/QRegExp>
 #include <QtCore/QStringList>
@@ -381,7 +381,7 @@ addComment:
     return true;
   }
 
-  if ( fieldname == QLatin1String( "mobile" ) ) { 	// mozilla/Netscape 7
+  if ( fieldname == QLatin1String( "mobile" ) ) {         // mozilla/Netscape 7
     a.insertPhoneNumber( PhoneNumber( value, PhoneNumber::Cell ) );
     return true;
   }
