@@ -44,7 +44,7 @@
 #include <kdebug.h>
 #include <kdatetime.h>
 #include <kstandarddirs.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QtCore/QString>
 #include <QtCore/QList>
@@ -62,7 +62,9 @@ class KCal::CalendarResources::Private
 {
   public:
     Private( const QString &family )
-      : mManager( new CalendarResourceManager( family ) ),
+      : mAddingInProgress( false ),
+        mLastUsedResource( 0 ),
+        mManager( new CalendarResourceManager( family ) ),
         mStandardPolicy( new StandardDestinationPolicy( mManager ) ),
         mDestinationPolicy( mStandardPolicy ),
         mAskPolicy( new AskDestinationPolicy( mManager ) ),
@@ -75,6 +77,9 @@ class KCal::CalendarResources::Private
       delete mStandardPolicy;
       delete mAskPolicy;
     }
+    bool mAddingInProgress;
+    ResourceCalendar *mLastUsedResource;
+
     bool mOpen;  //flag that indicates if the resources are "open"
 
     KRES::Manager<ResourceCalendar>* mManager;
@@ -157,6 +162,22 @@ CalendarResourceManager *CalendarResources::DestinationPolicy::resourceManager()
   return d->mManager;
 }
 
+bool CalendarResources::DestinationPolicy::hasCalendarResources()
+{
+  CalendarResourceManager::ActiveIterator it;
+  for ( it = resourceManager()->activeBegin();
+        it != resourceManager()->activeEnd(); ++it ) {
+    if ( !(*it)->readOnly() ) {
+      if ( resourceManager()->standardResource() == *it ) {
+        return true;
+      } else {
+        return true;
+      }
+    }
+  }
+  return false;
+}
+
 CalendarResources::StandardDestinationPolicy::StandardDestinationPolicy(
   CalendarResourceManager *manager, QWidget *parent )
   : DestinationPolicy( manager, parent ),
@@ -215,6 +236,10 @@ CalendarResources::CalendarResources( const KDateTime::Spec &timeSpec,
   : Calendar( timeSpec ),
     d( new KCal::CalendarResources::Private( family ) )
 {
+
+  connect( this, SIGNAL(batchAddingBegins()), this, SLOT(beginAddingIncidences()) );
+  connect( this, SIGNAL(batchAddingEnds()), this, SLOT(endAddingIncidences()) );
+
   d->mManager->addObserver( this );
 }
 
@@ -223,6 +248,9 @@ CalendarResources::CalendarResources( const QString &timeZoneId,
   : Calendar( timeZoneId ),
     d( new KCal::CalendarResources::Private( family ) )
 {
+  connect( this, SIGNAL(batchAddingBegins()), this, SLOT(beginAddingIncidences()) );
+  connect( this, SIGNAL(batchAddingEnds()), this, SLOT(endAddingIncidences()) );
+
   d->mManager->addObserver( this );
 }
 
@@ -404,7 +432,13 @@ bool CalendarResources::addIncidence( Incidence *incidence,
 bool CalendarResources::addIncidence( Incidence *incidence )
 {
   clearException();
-  ResourceCalendar *resource = d->mDestinationPolicy->destination( incidence );
+
+  ResourceCalendar *resource = d->mLastUsedResource;
+
+  if ( !d->mAddingInProgress || d->mLastUsedResource == 0 ) {
+    resource = d->mDestinationPolicy->destination( incidence );
+    d->mLastUsedResource = resource;
+  }
 
   if ( resource ) {
     d->mResourceMap[ incidence ] = resource;
@@ -582,10 +616,15 @@ Alarm::List CalendarResources::alarms( const KDateTime &from,
   return result;
 }
 
+bool CalendarResources::hasCalendarResources()
+{
+   return d->mDestinationPolicy->hasCalendarResources();
+}
+
 /****************************** PROTECTED METHODS ****************************/
 
 Event::List CalendarResources::rawEventsForDate( const QDate &date,
-                                                 const KDateTime::Spec &timespec,
+                                                 const KDateTime::Spec &timeSpec,
                                                  EventSortField sortField,
                                                  SortDirection sortDirection )
 {
@@ -593,19 +632,19 @@ Event::List CalendarResources::rawEventsForDate( const QDate &date,
   CalendarResourceManager::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     d->appendIncidences<Event::List>( result,
-                                      (*it)->rawEventsForDate( date, timespec ), *it );
+                                      (*it)->rawEventsForDate( date, timeSpec ), *it );
   }
-  return sortEvents( &result, sortField, sortDirection );
+  return sortEventsForDate( &result, date, timeSpec, sortField, sortDirection );
 }
 
 Event::List CalendarResources::rawEvents( const QDate &start, const QDate &end,
-                                          const KDateTime::Spec &timespec, bool inclusive )
+                                          const KDateTime::Spec &timeSpec, bool inclusive )
 {
   Event::List result;
   CalendarResourceManager::ActiveIterator it;
   for ( it = d->mManager->activeBegin(); it != d->mManager->activeEnd(); ++it ) {
     d->appendIncidences<Event::List>( result,
-                                      (*it)->rawEvents( start, end, timespec, inclusive ), *it );
+                                      (*it)->rawEvents( start, end, timeSpec, inclusive ), *it );
   }
   return result;
 }
@@ -639,6 +678,11 @@ bool CalendarResources::addJournal( Journal *journal )
   return addIncidence( journal );
 }
 
+bool CalendarResources::addJournal( Journal *journal, ResourceCalendar *resource )
+{
+  return addIncidence( journal, resource );
+}
+
 bool CalendarResources::deleteJournal( Journal *journal )
 {
   bool status;
@@ -667,12 +711,6 @@ void CalendarResources::deleteAllJournals()
   }
 }
 
-bool CalendarResources::addJournal( Journal *journal,
-                                    ResourceCalendar *resource )
-{
-  return addIncidence( journal, resource );
-}
-
 Journal *CalendarResources::journal( const QString &uid )
 {
   CalendarResourceManager::ActiveIterator it;
@@ -730,17 +768,15 @@ void CalendarResources::Private::appendIncidences( IncidenceList &result,
 
 void CalendarResources::connectResource( ResourceCalendar *resource )
 {
-  connect( resource, SIGNAL( resourceChanged( ResourceCalendar * ) ),
-           SIGNAL( calendarChanged() ) );
-  connect( resource, SIGNAL( resourceSaved( ResourceCalendar * ) ),
-           SIGNAL( calendarSaved() ) );
+  connect( resource, SIGNAL(resourceChanged(ResourceCalendar*)),
+           SIGNAL(calendarChanged()) );
+  connect( resource, SIGNAL(resourceSaved(ResourceCalendar*)),
+           SIGNAL(calendarSaved()) );
 
-  connect( resource, SIGNAL( resourceLoadError( ResourceCalendar *,
-                                                const QString & ) ),
-           SLOT( slotLoadError( ResourceCalendar *, const QString & ) ) );
-  connect( resource, SIGNAL( resourceSaveError( ResourceCalendar *,
-                                                const QString & ) ),
-           SLOT( slotSaveError( ResourceCalendar *, const QString & ) ) );
+  connect( resource, SIGNAL(resourceLoadError(ResourceCalendar*,QString)),
+           SLOT(slotLoadError(ResourceCalendar*,QString)) );
+  connect( resource, SIGNAL(resourceSaveError(ResourceCalendar*,QString)),
+           SLOT(slotSaveError(ResourceCalendar*,QString)) );
 }
 
 ResourceCalendar *CalendarResources::resource( Incidence *incidence )
@@ -889,6 +925,17 @@ bool CalendarResources::endChange( Incidence *incidence )
   return true;
 }
 
+void CalendarResources::beginAddingIncidences()
+{
+  d->mAddingInProgress = true;
+}
+
+void CalendarResources::endAddingIncidences()
+{
+  d->mAddingInProgress = false;
+  d->mLastUsedResource = 0;
+}
+
 int CalendarResources::incrementChangeCount( ResourceCalendar *r )
 {
   if ( !d->mChangeCounts.contains( r ) ) {
