@@ -27,7 +27,7 @@
 #include <kcmdlineargs.h>
 #include <kcomponentdata.h>
 #include <kdebug.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 
 #include <QtCore/QCoreApplication>
 
