@@ -46,6 +46,8 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QDrag>
+#include <QDate>
+#include <QWidget>
 #include <QDropEvent>
 #include <QPixmap>
 
@@ -164,6 +166,8 @@ QMimeData *DndFactory::createMimeData( const Incidence::Ptr &incidence )
 {
   MemoryCalendar::Ptr cal( new MemoryCalendar( d->mCalendar->timeSpec() ) );
   Incidence::Ptr i( incidence->clone() );
+  //strip recurrence id's, We don't want to drag the exception but the occurrence.
+  i->setRecurrenceId( KDateTime() );
   cal->addIncidence( i );
 
   QMimeData *mimeData = new QMimeData;
@@ -220,7 +224,7 @@ MemoryCalendar::Ptr DndFactory::createDropCalendar( QDropEvent *dropEvent )
 
 Event::Ptr DndFactory::createDropEvent( const QMimeData *mimeData )
 {
-  kDebug();
+  //kDebug();
   Event::Ptr event;
   MemoryCalendar::Ptr calendar( createDropCalendar( mimeData ) );
 
@@ -246,7 +250,7 @@ Event::Ptr DndFactory::createDropEvent( QDropEvent *dropEvent )
 
 Todo::Ptr DndFactory::createDropTodo( const QMimeData *mimeData )
 {
-  kDebug();
+  //kDebug();
   Todo::Ptr todo;
   MemoryCalendar::Ptr calendar( createDropCalendar( mimeData ) );
 
