@@ -22,7 +22,7 @@
 #include "identity.h"
 
 #include <kactioncollection.h>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kdebug.h>
 #include <kdialog.h>
 #include <klineedit.h>
@@ -30,6 +30,7 @@
 #include <kshellcompletion.h>
 #include <ktoolbar.h>
 #include <krun.h>
+#include <KUrl>
 #include <KComboBox>
 #include <KStandardDirs>
 
